ESMValTool Core API Reference
=============================

ESMValCore is mostly used as a commandline tool. However, it is also possibly to use (parts of) ESMValTool as a
library. This section documents the public API of ESMValCore.

.. toctree::

   esmvalcore.cmor
   esmvalcore.preprocessor
   esmvalcore.api
